import { latex_types } from "./symbol_types";

export default {
	displaymath: { insertText: "displaymath", detail: "math environment", documentation: "displaymath", kind: latex_types.environment },
	align: { insertText: "align", detail: "math environment", documentation: "align", kind: latex_types.environment },
	"align*": { insertText: "align*", detail: "math environment", documentation: "align*", kind: latex_types.environment },
	flalign: { insertText: "flalign", detail: "math environment", documentation: "flalign", kind: latex_types.environment },
	"flalign*": { insertText: "flalign*", detail: "math environment", documentation: "flalign*", kind: latex_types.environment },
	gather: { insertText: "gather", detail: "math environment", documentation: "gather", kind: latex_types.environment },
	"gather*": { insertText: "gather*", detail: "math environment", documentation: "gather*", kind: latex_types.environment },
	equation: { insertText: "equation", detail: "math environment", documentation: "equation", kind: latex_types.environment },
	subequation: { insertText: "subequation", detail: "\\begin{subequation}\\begin{<eqenv>} ...", documentation: "An equation to encapsulate a multi-equation environemnt for sub labeling", kind: latex_types.environment },
	multline: { insertText: "multline", detail: "math environment", documentation: "multline", kind: latex_types.environment },
	split: { insertText: "split", detail: "math environment", documentation: "split", kind: latex_types.environment },

	minipage: { insertText: "minipage", detail: "\\begin{minipage}[<pos>]{<width>} ... \\end{minipage}", documentation: "minipage", kind: latex_types.environment },

	itemize: { insertText: "itemize", detail: "Use \\item for list entrie", documentation: "Creates a simple List.", kind: latex_types.environment },
	enumerate: { insertText: "enumerate", detail: "Use \\item for list entrie", documentation: "Creates a numbered List.", kind: latex_types.environment },
	description: { insertText: "description", detail: "Use \\item[element] for a discription entrie", documentation: "Creates a List of \"element\" discriptions.", kind: latex_types.environment },

	flushleft: { insertText: "flushleft", documentation: "Alignes Text left.", kind: latex_types.environment },
	flusright: { insertText: "flusright", documentation: "Alignes Text right.", kind: latex_types.environment },
	center: { insertText: "center", documentation: "Alignes Text centered.", kind: latex_types.environment },

	quotation: { insertText: "quotation", documentation: "The quotation environment is useful for longer quotes going over several paragraphs, because it indents the first line of each paragraph.", kind: latex_types.environment },
	verse: { insertText: "verse", documentation: "The verse environment is useful for poems where the line breaks are important. The lines are separated by issuing a \\\\ at the end of a line and an empty line after each verse.", kind: latex_types.environment },
	abstract: { insertText: "abstract", documentation: "An environment for an abstract.", kind: latex_types.environment },

	tikzpicture: { insertText: "tikzpicture", documentation: "The \"TeX Ist Kein Zeichnprogram\" environment\nNeeds \\usepackage{tikz}", kind: latex_types.environment },

	verbatim: { insertText: "verbatim", detail: "Do not use verbatim environment and the \\verb command within parameters of other commands.", documentation: "Environment content will be directly printed, as if typed on a typewriter, with all line breaks and spaces, without any LaTeX command being executed.", kind: latex_types.environment },
	"verbatim*": { insertText: "verbatim*", detail: "Do not use verbatim environment and the \\verb command within parameters of other commands.", documentation: "Environment content will be directly printed, as if typed on a typewriter, with all line breaks and spaces, without any LaTeX command being executed. The additional * lets spaces be printed visible.", kind: latex_types.environment },

	tabular: { insertText: "tabular", detail: "Use \"&\" for jump to the next column, \"\\\\\" for a line break and \"\\hline\" for inserts a horizontal line", documentation: "The table spec argument of the \\begin{tabular}[pos]{table spec} command defines the format of the table. Use an \"l\" for a column of left-aligned text, \"r\" for right-aligned text, and \"c\" for centred text; p{width} for a column containing justified text with line breaks, and \"|\" for a vertical line. The pos argument specifies the vertical position of the table relative to the baseline of the surrounding text. Use either of the letters \"t\", \"b\" or \"c\" to specify table alignment at the top, bottom or center. The column separator can be specified with the @{...} construct. This command kills the inter-column space and replaces it with whatever is between the curly braces.", kind: latex_types.environment },

	figure: { documentation: "Any material enclosed in a \"figure\" or \"table\" environment will be treated as floating matter. Both float environments support an optional parameter called the placement specifier. The placement specifier is a combination of \"h\" \(hier\), \"b\" \(bottom\), \"p\" \(page\), \"!\" \(without considering most of the internal parameters\)].", kind: latex_types.environment },

	cases: { documentation: "cases", kind: latex_types.environment },

	array: { documentation: "The \\\\begin{array}{line-positioning} command with \"line-positioning\" is \"l\" \(left\), \"c\" \(richt\) or \"r\" \(right\) for each column. Use \"&\" to for next column and \"\\\\\" for linebreaks.", kind: latex_types.environment },
	matrix: { detail: "max 10 column", documentation: "Matrix without delimiters.", kind: latex_types.environment },
	pmatrix: { detail: "max 10 column", documentation: "Matrix with \( as delimiters.", kind: latex_types.environment },
	bmatrix: { detail: "max 10 column", documentation: "Matrix with [ as delimiters.", kind: latex_types.environment },
	Bmatrix: { detail: "max 10 column", documentation: "Matrix with { as delimiters.", kind: latex_types.environment },
	vmatrix: { detail: "max 10 column", documentation: "Matrix with | as delimiters.", kind: latex_types.environment },
	Vmatrix: { detail: "max 10 column", documentation: "Matrix with || as delimiters.", kind: latex_types.environment },

	tizkpicture: { insertText: "tizkpicture", detail: "Requires Package \"tikz\"", documentation: "", kind: latex_types.environment },

	lstlisting: { insertText: "lstlisting", detail: "Requires Package \"listings\"", documentation: "", kind: latex_types.environment },


	rmfamily: { documentation: "Font: Roman.", kind: latex_types.environment },
	itshape: { documentation: "Font: Italics.", kind: latex_types.environment },
	mdseries: { documentation: "Font: Medium weight (default).", kind: latex_types.environment },
	bfseries: { documentation: "Font: Boldface.", kind: latex_types.environment },
	upshape: { documentation: "Font: Upright (default).", kind: latex_types.environment },
	slshape: { documentation: "Font: Slanted.", kind: latex_types.environment },
	sffamily: { documentation: "Font: Sans serif.", kind: latex_types.environment },
	scshape: { documentation: "Font: Small caps.", kind: latex_types.environment },
	ttfamily: { documentation: "Font: Typewriter.", kind: latex_types.environment },
	normalfont: { documentation: "Font: Main document font.", kind: latex_types.environment },


};
