import { latex_types } from "./symbol_types";

export default {
    tikzstyle: {
        detail: "tikzstyle{<style name>}=[<options>]",
        insertText: "tikzstyle{${1:<style name>}}=[${2:<options>}]",
        documentation: "Sets style options refered by <style name>."
    },

    node: {
        documentation: "node",
        kind: latex_types.keyword,
        additionalInserts: {
            label: "node(<name>) at (<position>);",
            insertText: "node(${1:<name>}) at (${2:<position>});$0",
            kind: latex_types.snippet
        },
    },
    coordinate: {
        documentation: "coordinate",
        kind: latex_types.keyword,
        additionalInserts: {
            label: "coordinate(<name>) at (<position>);",
            insertText: "coordinate(${1:<name>}) at (${2:<position>});$0",
            kind: latex_types.snippet
        },
    },

    path: {
        documentation: "path",
        kind: latex_types.keyword,
        additionalInserts: [ { label: "path[<options>]", insertText: "path[${1:<options>}] $0", kind: latex_types.snippet } ]
    },
    draw: {
        documentation: "Inside {tikzpicture} this is an abbreviation for \path[draw].",
        kind: latex_types.keyword,
        additionalInserts: [ {
            label: "draw[<options>]",
            insertText: "draw[${1:<options>}] $0",
            kind: latex_types.snippet
        }, {
            label: "draw plot",
            insertText: "draw[${1:<options>}, domain=${2:<from>}:${3:<to>}] plot (\\x, {${4:<f(\\x)>}});$0",
            kind: latex_types.snippet
        } ]
    },
    fill: {
        documentation: "Inside {tikzpicture} this is an abbreviation for \path[fill].",
        kind: latex_types.keyword,
        additionalInserts: [ { label: "fill[<options>]", insertText: "fill[${1:<options>}] $0", kind: latex_types.snippet } ]
    },
    filldraw: {
        documentation: "Inside {tikzpicture} this is an abbreviation for \path[fill,draw].",
        kind: latex_types.keyword,
        additionalInserts: [ { label: "filldraw[<options>]", insertText: "filldraw[${1:<options>}] $0", kind: latex_types.snippet } ]
    },
    pattern: {
        documentation: "Inside {tikzpicture} this is an abbreviation for \path[pattern].",
        kind: latex_types.keyword,
        additionalInserts: [ { label: "pattern[<options>]", insertText: "pattern[${1:<options>}] $0", kind: latex_types.snippet } ]
    },
    shade: {
        documentation: "Inside {tikzpicture} this is an abbreviation for \path[shade].",
        kind: latex_types.keyword,
        additionalInserts: [ { label: "shade[<options>]", insertText: "shade[${1:<options>}] $0", kind: latex_types.snippet } ]
    },
    shadedraw: {
        documentation: "Inside {tikzpicture} this is an abbreviation for \path[shade,draw].",
        kind: latex_types.keyword,
        additionalInserts: [ { label: "shadedraw[<options>]", insertText: "shadedraw[${1:<options>}] $0", kind: latex_types.snippet } ]
    },
    clip: {
        documentation: "Inside {tikzpicture} this is an abbreviation for \path[clip].",
        kind: latex_types.keyword,
        additionalInserts: [ { label: "clip[<options>]", insertText: "clip[${1:<options>}] $0", kind: latex_types.snippet } ]
    },
    useasboundingbox: {
        kind: latex_types.keyword,
        documentation: "Inside {tikzpicture} this is an abbreviation for \path[use as bounding box].",
        additionalInserts: [ { label: "useasboundingbox[<options>]", insertText: "useasboundingbox[${1:<options>}] $0", kind: latex_types.snippet } ]
    },


    foreach: { insertText: "foreach ${1:\\x} in { $2 } $3;", documentation: "for loop", kind: latex_types.snippet },
    "begin\{scope\}": { insertText: "begin{scope}\n\t$0\n\\end{scope}", documentation: "scope environment", kind: latex_types.snippet },
};
